import { Pagination, Empty, Skeleton } from "antd";
import CourseCard from "../../../../app/main/courses/components/CourseCard";
import { courseDetailSelect, CourseDto, Prisma } from "@nice/common";
import { api } from "@nice/client";
import { DefaultArgs } from "@prisma/client/runtime/library";
import { useEffect, useMemo, useState } from "react";
interface CourseListProps {
	params?: {
		page?: number;
		pageSize?: number;
		where?: Prisma.PostWhereInput;
		select?: Prisma.PostSelect<DefaultArgs>;
	};
	cols?: number;
	showPagination?: boolean;
}
interface CoursesPagnationProps {
	data: {
		items: CourseDto[];
		totalPages: number;
	};
	isLoading: boolean;
}
export default function CourseList({
	params,
	cols = 3,
	showPagination = true,
}: CourseListProps) {
	const [currentPage, setCurrentPage] = useState<number>(params?.page || 1);
	const { data, isLoading }: CoursesPagnationProps =
		api.post.findManyWithPagination.useQuery({
			select: courseDetailSelect,
			...params,
			page: currentPage,
		});
	const totalPages = useMemo(() => {
		if (data && !isLoading) {
			return data?.totalPages;
		}
		return 1;
	}, [data, isLoading]);

	const courses = useMemo(() => {
		if (data && !isLoading) {
			return data?.items;
		}
		return [];
	}, [data, isLoading]);

	useEffect(() => {
		setCurrentPage(params?.page || 1);
	}, [params?.page, params]);
	function onPageChange(page: number, pageSize: number) {
		setCurrentPage(page);
		window.scrollTo({ top: 0, behavior: "smooth" });
	}
	if (isLoading) {
		return <Skeleton paragraph={{ rows: 10 }}></Skeleton>;
	}
	return (
		<div className="space-y-6">
			{courses.length > 0 ? (
				<>
					<div className={`grid lg:grid-cols-${cols} gap-6`}>
						{isLoading ? (
							<Skeleton paragraph={{ rows: 5 }}></Skeleton>
						) : (
							courses.map((course) => (
								<CourseCard key={course.id} course={course} />
							))
						)}
					</div>
					{showPagination && (
						<div className="flex justify-center mt-8">
							<Pagination
								current={currentPage}
								total={totalPages * params.pageSize}
								pageSize={params?.pageSize}
								onChange={onPageChange}
								showSizeChanger={false}
							/>
						</div>
					)}
				</>
			) : (
				<Empty description="暂无相关课程" />
			)}
		</div>
	);
}
